@@ -1,68 +1,69 @@
 from django.urls import include, re_path
 from rest_framework import routers
 
-from xauth import views
 from xauth.utils.settings import *
+from xauth.views import sign_in, sign_out, signup, verification, activation, password, profile
+from xauth.views.security_question import admin, AddSecurityQuestionView
 
 __router = routers.DefaultRouter()
-__router.register(r'security-questions', views.SecurityQuestionView)
+__router.register(r'security-questions', admin.SecurityQuestionView)
 
 app_name = 'xauth'
 urlpatterns = [
     re_path(r'^', include(__router.urls)),
     re_path(
         r'^signout/',
-        view=views.SignOutView.as_view(),
+        view=sign_out.SignOutView.as_view(),
         name='signout',
     ),
     re_path(
         r'^signin/',
-        view=views.SignInView.as_view(),
+        view=sign_in.SignInView.as_view(),
         name='signin',
     ),
     re_path(
         r'^signup/',
-        view=views.SignUpView.as_view(),
+        view=signup.SignUpView.as_view(),
         name='signup',
     ),
     re_path(
         r'^%s' % PROFILE_ENDPOINT,
-        view=views.ProfileView.as_view(),
+        view=profile.ProfileView.as_view(),
         name='profile',
     ),
     re_path(
         r'^verification/request/',
-        view=views.VerificationRequestView.as_view(),
+        view=verification.VerificationRequestView.as_view(),
         name='verification-request',
     ),
     re_path(
         r'^%s' % VERIFICATION_ENDPOINT,
-        view=views.VerificationConfirmView.as_view(),
+        view=verification.VerificationConfirmView.as_view(),
         name='verification-confirm',
     ),
     re_path(
         r'^password/reset/request/',
-        view=views.PasswordResetRequestView.as_view(),
+        view=password.PasswordResetRequestView.as_view(),
         name='password-reset-request',
     ),
     re_path(
         r'^%s' % PASSWORD_RESET_ENDPOINT,
-        view=views.PasswordResetConfirmView.as_view(),
+        view=password.PasswordResetConfirmView.as_view(),
         name='password-reset-confirm',
     ),
     re_path(
         r'^activation/request/',
-        view=views.ActivationRequestView.as_view(),
+        view=activation.ActivationRequestView.as_view(),
         name='activation-request',
     ),
     re_path(
         r'^%s' % ACTIVATION_ENDPOINT,
-        view=views.ActivationConfirmView.as_view(),
+        view=activation.ActivationConfirmView.as_view(),
         name='activation-confirm',
     ),
     re_path(
         r'^security-question/add/',
-        view=views.AddSecurityQuestionView.as_view(),
+        view=AddSecurityQuestionView.as_view(),
         name='security-question-add',
     ),
 ]
